==> NetworkManager-0.9.4.0.tar.xz: NetworkManager-0.9.4.0/libnm-glib/nm-glib-marshal.h <==

#ifndef ___nm_glib_marshal_MARSHAL_H__
#define ___nm_glib_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,STRING,STRING (nm-glib-marshal.list:1) */
extern void _nm_glib_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* VOID:UINT,UINT (nm-glib-marshal.list:2) */
extern void _nm_glib_marshal_VOID__UINT_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:UINT,UINT,UINT (nm-glib-marshal.list:3) */
extern void _nm_glib_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

G_END_DECLS

#endif /* ___nm_glib_marshal_MARSHAL_H__ */

==> NetworkManager-0.9.8.8.tar.xz: NetworkManager-0.9.8.8/libnm-glib/nm-glib-marshal.h <==

#ifndef ___nm_glib_marshal_MARSHAL_H__
#define ___nm_glib_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:POINTER,POINTER (nm-glib-marshal.list:1) */
extern void _nm_glib_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
                                                    const GValue *param_values,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);

/* VOID:STRING,STRING,STRING (nm-glib-marshal.list:2) */
extern void _nm_glib_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
                                                         const GValue *param_values,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);

/* VOID:UINT,UINT (nm-glib-marshal.list:3) */
extern void _nm_glib_marshal_VOID__UINT_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:UINT,UINT,UINT (nm-glib-marshal.list:4) */
extern void _nm_glib_marshal_VOID__UINT_UINT_UINT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
                                                   const GValue *param_values,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);

G_END_DECLS

#endif /* ___nm_glib_marshal_MARSHAL_H__ */
